@@ -26,10 +26,10 @@ class MyCallbacks(DefaultCallbacks):
     @override(DefaultCallbacks)
     def on_learn_on_batch(self, *, policy, train_batch, result, **kwargs):
         assert train_batch.count == 201
-        assert sum(train_batch.seq_lens) == 201
-        for k, v in train_batch.data.items():
+        assert sum(train_batch["seq_lens"]) == 201
+        for k, v in train_batch.items():
             if k == "state_in_0":
-                assert len(v) == len(train_batch.seq_lens)
+                assert len(v) == len(train_batch["seq_lens"])
             else:
                 assert len(v) == 201
         current = None
@@ -90,7 +90,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
                 config["num_envs_per_worker"] * \
                 config["rollout_fragment_length"]
             assert sample_batch.count == expected_count
-            for v in sample_batch.data.values():
+            for v in sample_batch.values():
                 assert len(v) == expected_count
             trainer.stop()
 
@@ -195,7 +195,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
         rollout_worker_w_api.policy_map[DEFAULT_POLICY_ID].view_requirements[
             "dones"] = ViewRequirement()
         batch = rollout_worker_w_api.sample()
-        self.assertTrue("next_actions" in batch.data)
+        self.assertTrue("next_actions" in batch)
         expected_a_ = None  # expected next action
         for i in range(len(batch["actions"])):
             a, d, a_ = batch["actions"][i], batch["dones"][i], \
@@ -218,7 +218,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
             "pol0": (EpisodeEnvAwareLSTMPolicy, obs_space, action_space, {}),
         }
 
-        def policy_fn(agent_id):
+        def policy_fn(agent_id, episode, **kwargs):
             return "pol0"
 
         config = {
@@ -257,7 +257,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
 
             result = rollout_worker_wo_api.sample()
             pol_batch_wo = result.policy_batches["pol0"]
-            check(pol_batch_w.data, pol_batch_wo.data)
+            check(pol_batch_w, pol_batch_wo)
 
     def test_traj_view_attention_functionality(self):
         action_space = Box(-float("inf"), float("inf"), shape=(3, ))
@@ -269,7 +269,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
                      {}),
         }
 
-        def policy_fn(agent_id):
+        def policy_fn(agent_id, episode, **kwargs):
             return "pol0"
 
         config = {
@@ -309,7 +309,7 @@ class TestTrajectoryViewAPI(unittest.TestCase):
                 "p0": (None, obs_space, action_space, {}),
                 "p1": (None, obs_space, action_space, {}),
             },
-            "policy_mapping_fn": lambda aid: "p{}".format(aid),
+            "policy_mapping_fn": lambda aid, **kwargs: "p{}".format(aid),
             "count_steps_by": "agent_steps",
         }
         tune.register_env(
